@@ -55,12 +55,45 @@ void writeCountdownSettings (CountdownPlugin *desktop_plugin)
 	g_free (filename);
 }
 
+void select_date (GtkButton *button, GtkWidget *dialog)
+{	
+	guint year, month, day;
+	HildonTouchSelector *selector = hildon_picker_dialog_get_selector (HILDON_PICKER_DIALOG (dialog));
+	
+	gtk_dialog_run (GTK_DIALOG (dialog));
+	hildon_date_selector_get_date (HILDON_DATE_SELECTOR (selector), &year, &month, &day);
+	GDate *date = g_date_new_dmy (day, month+1, year);
+	gchar dateString[100];
+	g_date_strftime (dateString, 99, "%A %d %B %Y", date);
+	gtk_button_set_label (button, dateString);
+	g_date_free (date);
+
+	gtk_widget_hide (dialog);
+}
+
+void select_time (GtkButton *button, GtkWidget *dialog)
+{
+	guint hour, minute;
+	HildonTouchSelector *selector = hildon_picker_dialog_get_selector (HILDON_PICKER_DIALOG (dialog));
+	
+	gtk_dialog_run (GTK_DIALOG (dialog));
+	hildon_time_selector_get_time (HILDON_TIME_SELECTOR (selector), &hour, &minute);
+	gchar *timeString = g_strdup_printf ("%02d:%02d", hour, minute);
+	gtk_button_set_label (button, timeString);
+	g_free (timeString);
+	
+	gtk_widget_hide (dialog);
+}
+
 void addNewCountdown_clicked(GtkButton *button, CountdownPlugin *desktop_plugin)
 {
 	//g_warning ("addNewCountdown_clicked");
+	GDate *date = g_date_new();
     GtkWidget *dialog, *content_area;
     GtkWidget *titleEntry, *dateButton, *timeButton;
     GtkWidget *titleCaption, *dateCaption, *timeCaption;
+	GtkWidget *datePicker, *timePicker;
+	GtkWidget *dateSelector, *timeSelector;
     GtkWidget *toggleYears, *toggleWeeks, *toggleDays, *toggleHours, *toggleMinutes;
     GtkWidget *displayCaption;
     GtkSizeGroup *group = gtk_size_group_new (GTK_SIZE_GROUP_HORIZONTAL);
@@ -76,16 +109,37 @@ void addNewCountdown_clicked(GtkButton *button, CountdownPlugin *desktop_plugin)
 	hildon_caption_set_separator (HILDON_CAPTION (titleCaption), "");
     gtk_container_add (GTK_CONTAINER (content_area), titleCaption);
 
-    dateButton = hildon_date_button_new (HILDON_SIZE_AUTO_WIDTH | HILDON_SIZE_FINGER_HEIGHT, HILDON_BUTTON_ARRANGEMENT_VERTICAL);
-    hildon_button_set_title_alignment (HILDON_BUTTON (dateButton), 0.5, 0.5);
-    hildon_button_set_value_alignment (HILDON_BUTTON (dateButton), 0.5, 0.5);
+	datePicker = hildon_picker_dialog_new (GTK_WINDOW (dialog));
+	gtk_window_set_title (GTK_WINDOW (datePicker), "Select date");
+	dateSelector = hildon_date_selector_new ();
+	hildon_picker_dialog_set_selector (HILDON_PICKER_DIALOG (datePicker), HILDON_TOUCH_SELECTOR (dateSelector));
+	g_date_set_time_t (date, time(NULL));
+	gchar dateString[100];
+	g_date_strftime (dateString, 99, "%A %d %B %Y", date);
+	
+	dateButton = hildon_gtk_button_new (HILDON_SIZE_AUTO_WIDTH | HILDON_SIZE_FINGER_HEIGHT);
+	hildon_date_selector_select_current_date (HILDON_DATE_SELECTOR (dateSelector), g_date_get_year (date), g_date_get_month (date) - 1, g_date_get_day (date));
+	gtk_button_set_label (GTK_BUTTON (dateButton), dateString);
+	g_signal_connect (G_OBJECT (dateButton), "clicked", G_CALLBACK (select_date), datePicker);
+	
     dateCaption = hildon_caption_new (group, "Date", dateButton, NULL, HILDON_CAPTION_MANDATORY);
 	hildon_caption_set_separator (HILDON_CAPTION (dateCaption), "");
     gtk_container_add (GTK_CONTAINER (content_area), dateCaption);
 
-    timeButton = hildon_time_button_new (HILDON_SIZE_AUTO_WIDTH | HILDON_SIZE_FINGER_HEIGHT, HILDON_BUTTON_ARRANGEMENT_VERTICAL);
-    hildon_button_set_title_alignment (HILDON_BUTTON (timeButton), 0.5, 0.5);
-    hildon_button_set_value_alignment (HILDON_BUTTON (timeButton), 0.5, 0.5);
+	timePicker = hildon_picker_dialog_new (GTK_WINDOW (dialog));
+	gtk_window_set_title (GTK_WINDOW (timePicker), "Select time");
+	timeSelector = hildon_time_selector_new ();
+	hildon_picker_dialog_set_selector (HILDON_PICKER_DIALOG (timePicker), HILDON_TOUCH_SELECTOR (timeSelector));
+	time_t now = time (NULL);
+	struct tm *timeinfo = localtime(&now);
+	gchar *timeString = g_strdup_printf ("%02d:%02d", timeinfo->tm_hour, timeinfo->tm_min);
+	
+	timeButton = hildon_gtk_button_new (HILDON_SIZE_AUTO_WIDTH | HILDON_SIZE_FINGER_HEIGHT);
+	hildon_time_selector_set_time (HILDON_TIME_SELECTOR (timeSelector), timeinfo->tm_hour, timeinfo->tm_min);
+	gtk_button_set_label (GTK_BUTTON (timeButton), timeString);
+	g_free (timeString);
+	g_signal_connect (G_OBJECT (timeButton), "clicked", G_CALLBACK (select_time), timePicker);
+	
     timeCaption = hildon_caption_new (group, "Time", timeButton, NULL, HILDON_CAPTION_MANDATORY);
 	hildon_caption_set_separator (HILDON_CAPTION (timeCaption), "");
     gtk_container_add (GTK_CONTAINER (content_area), timeCaption);
@@ -109,6 +163,7 @@ void addNewCountdown_clicked(GtkButton *button, CountdownPlugin *desktop_plugin)
     displayCaption = hildon_caption_new (group, "Display", GTK_WIDGET (hbox), NULL, HILDON_CAPTION_MANDATORY);
 	hildon_caption_set_separator (HILDON_CAPTION (displayCaption), "");
     gtk_container_add (GTK_CONTAINER (content_area), displayCaption);
+	g_date_free (date);
     
     gtk_widget_show_all (dialog);
 
@@ -122,8 +177,8 @@ void addNewCountdown_clicked(GtkButton *button, CountdownPlugin *desktop_plugin)
         gchar *printDate, *printTime, *compTime;
 		GtkTreeIter iter;
 
-        hildon_date_button_get_date (HILDON_DATE_BUTTON (dateButton), &year, &month, &day);
-        hildon_time_button_get_time (HILDON_TIME_BUTTON (timeButton), &hours, &minutes);
+        hildon_date_selector_get_date (HILDON_DATE_SELECTOR (dateSelector), &year, &month, &day);
+        hildon_time_selector_get_time (HILDON_TIME_SELECTOR (timeSelector), &hours, &minutes);
 
         printDate = g_strdup_printf ("%02d/%02d/%02d",year,month+1,day);
         printTime = g_strdup_printf ("%02d:%02d", hours, minutes);
@@ -156,6 +211,8 @@ void modifyCountdown_clicked (GtkButton *button, CountdownPlugin *desktop_plugin
 	GtkWidget *dialog, *content_area;
     GtkWidget *titleEntry, *dateButton, *timeButton;
     GtkWidget *titleCaption, *dateCaption, *timeCaption;
+	GtkWidget *datePicker, *timePicker;
+	GtkWidget *dateSelector, *timeSelector;
     GtkWidget *toggleYears, *toggleWeeks, *toggleDays, *toggleHours, *toggleMinutes;
     GtkWidget *displayCaption;
     GtkSizeGroup *group = gtk_size_group_new (GTK_SIZE_GROUP_HORIZONTAL);
@@ -171,16 +228,26 @@ void modifyCountdown_clicked (GtkButton *button, CountdownPlugin *desktop_plugin
 	hildon_caption_set_separator (HILDON_CAPTION (titleCaption), "");
     gtk_container_add (GTK_CONTAINER (content_area), titleCaption);
 
-    dateButton = hildon_date_button_new (HILDON_SIZE_AUTO_WIDTH | HILDON_SIZE_FINGER_HEIGHT, HILDON_BUTTON_ARRANGEMENT_VERTICAL);
-    hildon_button_set_title_alignment (HILDON_BUTTON (dateButton), 0.5, 0.5);
-    hildon_button_set_value_alignment (HILDON_BUTTON (dateButton), 0.5, 0.5);
+	datePicker = hildon_picker_dialog_new (GTK_WINDOW (dialog));
+	gtk_window_set_title (GTK_WINDOW (datePicker), "Select date");
+	dateSelector = hildon_date_selector_new ();
+	hildon_picker_dialog_set_selector (HILDON_PICKER_DIALOG (datePicker), HILDON_TOUCH_SELECTOR (dateSelector));
+	
+	dateButton = hildon_gtk_button_new (HILDON_SIZE_AUTO_WIDTH | HILDON_SIZE_FINGER_HEIGHT);
+	g_signal_connect (G_OBJECT (dateButton), "clicked", G_CALLBACK (select_date), datePicker);
+	
     dateCaption = hildon_caption_new (group, "Date", dateButton, NULL, HILDON_CAPTION_MANDATORY);
 	hildon_caption_set_separator (HILDON_CAPTION (dateCaption), "");
     gtk_container_add (GTK_CONTAINER (content_area), dateCaption);
 
-    timeButton = hildon_time_button_new (HILDON_SIZE_AUTO_WIDTH | HILDON_SIZE_FINGER_HEIGHT, HILDON_BUTTON_ARRANGEMENT_VERTICAL);
-    hildon_button_set_title_alignment (HILDON_BUTTON (timeButton), 0.5, 0.5);
-    hildon_button_set_value_alignment (HILDON_BUTTON (timeButton), 0.5, 0.5);
+    timePicker = hildon_picker_dialog_new (GTK_WINDOW (dialog));
+	gtk_window_set_title (GTK_WINDOW (timePicker), "Select time");
+	timeSelector = hildon_time_selector_new ();
+	hildon_picker_dialog_set_selector (HILDON_PICKER_DIALOG (timePicker), HILDON_TOUCH_SELECTOR (timeSelector));
+
+	timeButton = hildon_gtk_button_new (HILDON_SIZE_AUTO_WIDTH | HILDON_SIZE_FINGER_HEIGHT);
+	g_signal_connect (G_OBJECT (timeButton), "clicked", G_CALLBACK (select_time), timePicker);
+	
     timeCaption = hildon_caption_new (group, "Time", timeButton, NULL, HILDON_CAPTION_MANDATORY);
 	hildon_caption_set_separator (HILDON_CAPTION (timeCaption), "");
     gtk_container_add (GTK_CONTAINER (content_area), timeCaption);
@@ -221,14 +288,23 @@ void modifyCountdown_clicked (GtkButton *button, CountdownPlugin *desktop_plugin
 		hour = time/(60 *60);
 		minute = time/60 - hour*60;
 		
+		gchar dateString[100];
+		g_date_strftime (dateString, 99, "%A %d %B %Y", &date);
+		
+		gchar *timeString = g_strdup_printf ("%02d:%02d", hour, minute);
+		
 		hildon_entry_set_text (HILDON_ENTRY (titleEntry), titleText);
-		hildon_date_button_set_date (HILDON_DATE_BUTTON (dateButton), year, month, day);
-		hildon_time_button_set_time (HILDON_TIME_BUTTON (timeButton), hour, minute);
+		hildon_date_selector_select_current_date (HILDON_DATE_SELECTOR (dateSelector), year, month, day);
+		gtk_button_set_label (GTK_BUTTON (dateButton), dateString);
+		hildon_time_selector_set_time (HILDON_TIME_SELECTOR (timeSelector), hour, minute);
+		gtk_button_set_label (GTK_BUTTON (timeButton), timeString);
 		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (toggleYears), tYears);
 		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (toggleWeeks), tWeeks);
 		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (toggleDays), tDays);
 		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (toggleHours), tHours);
 		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (toggleMinutes), tMinutes);
+		
+		g_free (timeString);
 	}
 	
     gtk_widget_show_all (dialog);
@@ -281,12 +357,12 @@ void modifyCountdown_clicked (GtkButton *button, CountdownPlugin *desktop_plugin
     gtk_widget_destroy (dialog);
 }
 
-void selection_changed (HildonTouchSelector *selector, GtkWidget *button)
+void select_refresh (GtkButton *button, GtkWidget *dialog)
 {
-	gchar *current_selection = NULL;
-	current_selection = hildon_touch_selector_get_current_text (selector);
-	hildon_button_set_title (HILDON_BUTTON (button), g_strconcat (current_selection, " minute(s)", NULL));
-	g_free (current_selection);
+	HildonTouchSelector *selector = hildon_picker_dialog_get_selector (HILDON_PICKER_DIALOG (dialog));
+	gtk_dialog_run (GTK_DIALOG (dialog));
+	gtk_button_set_label (button, hildon_touch_selector_get_current_text (selector));
+	gtk_widget_hide (dialog);
 }
 
 void globalOptions (HDHomePluginItem *hitem, CountdownPlugin *desktop_plugin)
@@ -302,23 +378,25 @@ void globalOptions (HDHomePluginItem *hitem, CountdownPlugin *desktop_plugin)
         "Save", GTK_RESPONSE_ACCEPT, NULL);
     content_area = gtk_dialog_get_content_area (GTK_DIALOG (dialog));
     
+	GtkWidget *picker = hildon_picker_dialog_new (GTK_WINDOW (dialog));
+	gtk_window_set_title (GTK_WINDOW (picker), "Update Every");
 	GtkWidget *selector = hildon_touch_selector_new_text ();
+	hildon_picker_dialog_set_selector (HILDON_PICKER_DIALOG (picker), HILDON_TOUCH_SELECTOR (selector));
 	
 	int i;
 	for (i=0; i<=60; i++)
 	{
-		gchar *text = g_strdup_printf ("%d", i);
+		gchar *text = g_strdup_printf ("%d minutes(s)", i);
 		hildon_touch_selector_append_text (HILDON_TOUCH_SELECTOR (selector), text);
+		g_free (text);
 	}
-	
 	hildon_touch_selector_set_active (HILDON_TOUCH_SELECTOR (selector), 0, desktop_plugin->refresh);
 	
-	refreshButton = hildon_picker_button_new (HILDON_SIZE_AUTO_WIDTH | HILDON_SIZE_FINGER_HEIGHT, HILDON_BUTTON_ARRANGEMENT_VERTICAL);
-	gchar *current_selection = hildon_touch_selector_get_current_text (HILDON_TOUCH_SELECTOR (selector));
-	hildon_button_set_title (HILDON_BUTTON (refreshButton), g_strconcat (current_selection, " minute(s)", NULL));
-	g_signal_connect (G_OBJECT (selector), "changed", G_CALLBACK (selection_changed), refreshButton);
+	refreshButton = hildon_gtk_button_new (HILDON_SIZE_AUTO_WIDTH | HILDON_SIZE_FINGER_HEIGHT);
+	g_signal_connect (G_OBJECT (refreshButton), "clicked", G_CALLBACK (select_refresh), picker);
 	
-	hildon_picker_button_set_selector (HILDON_PICKER_BUTTON (refreshButton), HILDON_TOUCH_SELECTOR (selector));
+	gchar *text = g_strdup_printf ("%d minute(s)", desktop_plugin->refresh);
+	gtk_button_set_label (GTK_BUTTON (refreshButton), text);
 	
 	refreshCaption = hildon_caption_new (group, "Update every", refreshButton, NULL, HILDON_CAPTION_MANDATORY);
 	hildon_caption_set_separator (HILDON_CAPTION (refreshCaption), "");
@@ -330,7 +408,8 @@ void globalOptions (HDHomePluginItem *hitem, CountdownPlugin *desktop_plugin)
     int response=gtk_dialog_run (GTK_DIALOG (dialog));
     if (response == GTK_RESPONSE_ACCEPT)
     {
-        desktop_plugin->refresh = hildon_picker_button_get_active (HILDON_PICKER_BUTTON (refreshButton));
+		gint refresh = hildon_touch_selector_get_active (HILDON_TOUCH_SELECTOR (selector), 0);
+		desktop_plugin->refresh = refresh;
 		
 		if (desktop_plugin->eventID != 0)
 		{
@@ -409,9 +488,7 @@ void setup_make_view ( CountdownPlugin *desktop_plugin )
 			hours=seconds/(60*60);
 			minutes=seconds/(60)-(hours*60);
 			readableTime=g_strdup_printf("%02d:%02d",hours,minutes);
-			
-			//g_warning("added entry from keyFile... title: %s", title);
-			
+						
 			gtk_list_store_append(desktop_plugin->entries, &iter);
 			gtk_list_store_set(desktop_plugin->entries, &iter,0,title,1,date,2,time,3,readableTime,4,showWhich[0],5,showWhich[1],6,showWhich[2],7,showWhich[3],8,showWhich[4],-1);
 			snprintf(entry,5,"%d",++i);
@@ -458,7 +535,6 @@ void countdown_content_create (CountdownPlugin *desktop_plugin)
 	//g_warning ("countdown_content_create");
     desktop_plugin->contents = gtk_vbox_new (0, FALSE);
 	GtkVBox *scrollArea = GTK_VBOX (gtk_vbox_new (0, TRUE));
-    //GtkLabel *label = GTK_LABEL (gtk_label_new ("Countdown widget"));
 
     GtkWidget *addNewCountdown;
     addNewCountdown = hildon_button_new (HILDON_SIZE_AUTO_WIDTH | HILDON_SIZE_AUTO_HEIGHT, HILDON_BUTTON_ARRANGEMENT_VERTICAL);
@@ -483,7 +559,6 @@ void countdown_content_create (CountdownPlugin *desktop_plugin)
     
     g_signal_connect (addNewCountdown, "clicked", G_CALLBACK (addNewCountdown_clicked), desktop_plugin);
     
-    //gtk_box_pack_start (GTK_BOX (desktop_plugin->homeWidget), GTK_WIDGET (label), FALSE, FALSE, 0);
     gtk_box_pack_start (GTK_BOX (desktop_plugin->homeWidget), GTK_WIDGET (hbox), FALSE, FALSE, 0);
     gtk_box_pack_start (GTK_BOX (desktop_plugin->homeWidget), GTK_WIDGET (buttons), FALSE, FALSE, 0);
     gtk_widget_show_all (desktop_plugin->homeWidget);
@@ -652,14 +727,13 @@ gboolean update_content (CountdownPlugin *desktop_plugin)
 		hildon_button_set_title_alignment (HILDON_BUTTON (countdownButton), 0.0, 0.5);
 		hildon_button_set_value_alignment (HILDON_BUTTON (countdownButton), 0.0, 0.5);
 		hildon_button_add_size_groups (HILDON_BUTTON (countdownButton), titleGroup, valueGroup, NULL);
-		gtk_window_set_opacity (gtk_widget_get_ancestor (countdownButton, GTK_TYPE_WINDOW), 0.5);
 		
 		g_signal_connect (countdownButton, "clicked", G_CALLBACK (modifyCountdown_clicked), desktop_plugin);
 		
 		gtk_box_pack_start (GTK_BOX (vbox), countdownButton, FALSE, FALSE, 0);
 		g_free (contentLabelText);
 		
-		gchar *name=g_strdup_printf("%d",count++);
+		gchar *name=g_strdup_printf("%d",desktop_plugin->offset + count++);
 		
 		gtk_widget_set_name (countdownButton, name);
 		
@@ -742,7 +816,7 @@ countdown_plugin_check_desktop (GObject *gobject, GParamSpec *pspec, CountdownPl
 	}
 }
 
-static void
+/*static void
 countdown_plugin_realize (GtkWidget *widget)
 {
 	GdkScreen *screen;
@@ -756,9 +830,9 @@ countdown_plugin_realize (GtkWidget *widget)
 
 	GTK_WIDGET_CLASS(g_type_class_peek_parent
 				 (GTK_FRAME_GET_CLASS(widget)))->realize(widget);
-}
+}*/
 
-static gboolean
+/*static gboolean
 countdown_plugin_expose_event (GtkWidget *widget, GdkEventExpose *event)
 {
 	//g_warning ("countdown_plugin_expose_event");
@@ -766,26 +840,24 @@ countdown_plugin_expose_event (GtkWidget *widget, GdkEventExpose *event)
 	
 	if (GTK_WIDGET_DRAWABLE(widget) == FALSE){
 		return FALSE;
-	}
+	}*/
 
-	//g_warning ("continuing...");
     /* Create cairo context */
-    cr = gdk_cairo_create (GDK_DRAWABLE (widget->window));
+    /*cr = gdk_cairo_create (GDK_DRAWABLE (widget->window));
     gdk_cairo_region (cr, event->region);
-    cairo_clip (cr);
+    cairo_clip (cr);*/
 
     /* Draw alpha background */
-    cairo_set_operator (cr, CAIRO_OPERATOR_SOURCE);
+    /*cairo_set_operator (cr, CAIRO_OPERATOR_SOURCE);
     cairo_set_source_rgba (cr, 0.0, 0.0, 0.0, 0.0);
-    cairo_paint (cr);
+    cairo_paint (cr);*/
 
     /* Free context */
-    cairo_destroy (cr);
+    /*cairo_destroy (cr);
 	
 	return GTK_WIDGET_CLASS(g_type_class_peek_parent
                          (GTK_FRAME_GET_CLASS(widget)))->expose_event(widget, event);
-	//return TRUE;
-}
+}*/
 
 static void
 countdown_plugin_finalize (GObject *object)
@@ -803,9 +875,6 @@ static void
 countdown_plugin_init (CountdownPlugin *desktop_plugin)
 {
 	//g_warning ("countdown_plugin_init");
-	//GdkScreen *screen = gtk_widget_get_screen (GTK_WIDGET (desktop_plugin));
-	//gtk_widget_set_colormap (GTK_WIDGET (desktop_plugin), gdk_screen_get_rgba_colormap (screen));
-	//gtk_widget_set_app_paintable (GTK_WIDGET (desktop_plugin), TRUE);
 	desktop_plugin->offset = 0;
 	desktop_plugin->eventID = 0;
 	hd_home_plugin_item_set_settings (&desktop_plugin->hitem, TRUE);
@@ -814,25 +883,19 @@ countdown_plugin_init (CountdownPlugin *desktop_plugin)
 	desktop_plugin->homeWidget = gtk_vbox_new (0, FALSE);
 	gtk_container_add (GTK_CONTAINER (desktop_plugin), desktop_plugin->homeWidget);
 	gtk_widget_show_all (desktop_plugin->homeWidget);
-	//gtk_widget_set_size_request (GTK_WIDGET (desktop_plugin), 300, 300);
 
 	setup_make_view (desktop_plugin);
-	g_object_ref (desktop_plugin->entries);
 
 	countdown_content_create (desktop_plugin);
-	//update_content(desktop_plugin);
-	//if (desktop_plugin->refresh > 0)
-	//	desktop_plugin->eventID = g_timeout_add (desktop_plugin->refresh*1000*60, (GSourceFunc)update_content, desktop_plugin);
 
 	g_signal_connect (&desktop_plugin->hitem, "notify::is-on-current-desktop", G_CALLBACK (countdown_plugin_check_desktop), desktop_plugin);
-	//g_signal_connect (&desktop_plugin->hitem, "destroy", G_CALLBACK (countdown_plugin_finalize), desktop_plugin);
 }
 
 static void
 countdown_plugin_class_init (CountdownPluginClass *klass)
 {
   GObjectClass *object_class = G_OBJECT_CLASS (klass);
-  GtkWidgetClass *widget_class = GTK_WIDGET_CLASS (klass);
+  //GtkWidgetClass *widget_class = GTK_WIDGET_CLASS (klass);
 
   object_class->finalize = countdown_plugin_finalize;
  
